@@ -24,9 +24,7 @@ class DataTransformer(BaseEstimator, TransformerMixin):
             
             user_id = row[self.USER_ID_KEY]
             movie_id = row[self.MOVIE_ID_KEY]
-            rating = row[self.RATING_KEY]
-            timestamp = row[self.TIMESTAMP_KEY]
-            features = self._get_features(user_id, movie_id, rating, timestamp)
+            features = self._get_features(user_id, movie_id)
             a = features[self.NB_PREVIOUS_RATINGS_KEY]
             b = features[self.AVG_RATINGS_PREVIOUS_KEY]
             s = pd.Series([a, b],index=[self.NB_PREVIOUS_RATINGS_KEY, self.AVG_RATINGS_PREVIOUS_KEY])
@@ -34,11 +32,7 @@ class DataTransformer(BaseEstimator, TransformerMixin):
             
         return df_transformed
     
-    def _get_features(self, user_id, movie_id, rating, timestamp):
-        features = self.db.loc[(self.db.userId == user_id) & (self.db.movieId == movie_id) & (self.db.rating == rating) & (self.db.timestamp == timestamp)]
-        if(len(features) > 0):
-            return features
-        
+    def _get_features(self, user_id, movie_id):
         user_ratings = self.db.loc[self.db.userId == user_id]
         idx_max = user_ratings[self.NB_PREVIOUS_RATINGS_KEY].idxmax()
-        return db.iloc[idx_max]
\ No newline at end of file
+        return self.db.iloc[idx_max]
\ No newline at end of file
